rpms/anacron/devel anacron-2.3-memleaking.patch, NONE, 1.1 anacron-2.3-pic.patch, NONE, 1.1 anacron.spec, 1.28, 1.29

fedora-cvs-commits at redhat.com fedora-cvs-commits at redhat.com
Mon Dec 4 10:33:36 UTC 2006


Author: mmaslano

Update of /cvs/dist/rpms/anacron/devel
In directory cvs.devel.redhat.com:/tmp/cvs-serv22975

Modified Files:
	anacron.spec 
Added Files:
	anacron-2.3-memleaking.patch anacron-2.3-pic.patch 
Log Message:
Rebuilt with changed patches.


anacron-2.3-memleaking.patch:
 global.h  |   31 +++++++++++++++++++------------
 gregor.c  |    2 +-
 lock.c    |    2 +-
 log.c     |   13 +++++++------
 matchrx.c |   25 +++++++++++++++++++++----
 runjob.c  |    6 +++---
 6 files changed, 52 insertions(+), 27 deletions(-)

--- NEW FILE anacron-2.3-memleaking.patch ---
diff -ur anacron-2.3.orig/global.h anacron-2.3/global.h
--- anacron-2.3.orig/global.h	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/global.h	2006-10-08 10:08:18.000000000 -0400
@@ -108,18 +108,25 @@
 /* main.c */
 int xopen(int fd, const char *file_name, int flags);
 void xclose(int fd);
-pid_t xfork();
+pid_t xfork(void);
+
+#ifdef __GNUC__
+#define PRINTF_FORMAT(n, m) \
+   __attribute__ ((format (printf, n, m)))
+#else
+#define PRINTF_FORMAT(n, m)
+#endif
 
 /* log.c */
-void explain(const char *fmt, ...);
-void explain_e(const char *fmt, ...);
-void complain(const char *fmt, ...);
-void complain_e(const char *fmt, ...);
-void die(const char *fmt, ...);
-void die_e(const char *fmt, ...);
-void xdebug(const char *fmt, ...);
-void xdebug_e(const char *fmt, ...);
-void xcloselog();
+void explain(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void explain_e(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void complain(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void complain_e(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void die(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void die_e(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void xdebug(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void xdebug_e(const char *fmt, ...)PRINTF_FORMAT(1,2);
+void xcloselog(void);
 
 #ifdef DEBUG
 #define Debug(args) xdebug args
@@ -130,8 +137,8 @@
 #endif /* not DEBUG */
 
 /* readtab.c */
-void read_tab();
-void arrange_jobs();
+void read_tab(void);
+void arrange_jobs(void);
 
 /* lock.c */
 int consider_job(job_rec *jr);
diff -ur anacron-2.3.orig/gregor.c anacron-2.3/gregor.c
--- anacron-2.3.orig/gregor.c	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/gregor.c	2006-10-08 10:24:05.000000000 -0400
@@ -25,7 +25,7 @@
 #include <limits.h>
 #include "gregor.h"
 
-const static int
+static const int
 days_in_month[] = {
     31,  /* Jan */
     28,  /* Feb (non-leap) */
diff -ur anacron-2.3.orig/lock.c anacron-2.3/lock.c
--- anacron-2.3.orig/lock.c	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/lock.c	2006-10-08 16:14:14.000000000 -0400
@@ -42,7 +42,7 @@
     jr->timestamp_fd = open(jr->ident, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR);
     if (jr->timestamp_fd == -1)
 	die_e("Can't open timestamp file for job %s", jr->ident);
-    fcntl(jr->timestamp_fd, F_SETFD, 1);    /* set close-on-exec flag */
+    fcntl(jr->timestamp_fd, F_SETFD, FD_CLOEXEC);  /* set close-on-exec flag */
     /* We want to own this file, and set its mode to 0600. This is necessary
      * in order to prevent other users from putting locks on it. */
     if (fchown(jr->timestamp_fd, getuid(), getgid()))
diff -ur anacron-2.3.orig/matchrx.c anacron-2.3/matchrx.c
--- anacron-2.3.orig/matchrx.c	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/matchrx.c	2006-10-08 10:29:24.000000000 -0400
@@ -26,6 +26,7 @@
 #include <regex.h>
 #include <stdarg.h>
 #include <stdlib.h>
+#include <string.h>
 #include "matchrx.h"
 
 int
@@ -49,11 +50,23 @@
 	sub_offsets = malloc(sizeof(regmatch_t) * (n_sub + 1));
 	memset(sub_offsets, 0, sizeof(regmatch_t) * (n_sub + 1));
 
-	if (regcomp(&crx, rx, REG_EXTENDED)) return - 1;
+	if (regcomp(&crx, rx, REG_EXTENDED))
+	{
+		free(sub_offsets);
+		return - 1;
+	}
 	r = regexec(&crx, string, n_sub + 1, sub_offsets, 0);
-	if (r != 0 && r != REG_NOMATCH) return - 1;
+	if (r != 0 && r != REG_NOMATCH)
+	{
+		free(sub_offsets);
+		return - 1;
+	}
 	regfree(&crx);
-	if (r == REG_NOMATCH) return 0;
+	if (r == REG_NOMATCH)
+	{
+		free(sub_offsets);
+		return 0;
+	}
 
 	va_start(va, n_sub);
 	n = 1;
@@ -62,7 +75,11 @@
 		substring = va_arg(va, char**);
 		if (substring != NULL)
 		{
-			if (sub_offsets[n].rm_so == -1) return - 1;
+			if (sub_offsets[n].rm_so == -1)
+			{
+				free(sub_offsets);
+				return - 1;
+			}
 			*substring = string + sub_offsets[n].rm_so;
 			*(string + sub_offsets[n].rm_eo) = 0;
 		}
diff -ur anacron-2.3.orig/runjob.c anacron-2.3/runjob.c
--- anacron-2.3.orig/runjob.c	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/runjob.c	2006-10-08 16:09:37.000000000 -0400
@@ -64,8 +64,8 @@
     if (fdin == -1) die_e("Can't open temporary file for reading");
     if (unlink(name)) die_e("Can't unlink temporary file");
     free(name);
-    fcntl(fdout, F_SETFD, 1);    /* set close-on-exec flag */
-    fcntl(fdin, F_SETFD, 1);    /* set close-on-exec flag */
+    fcntl(fdout, F_SETFD, FD_CLOEXEC);    /* set close-on-exec flag */
+    fcntl(fdin, F_SETFD, FD_CLOEXEC);    /* set close-on-exec flag */
 
     jr->input_fd = fdin;
     jr->output_fd = fdout;
@@ -178,7 +178,7 @@
     pid = xfork();
     if (pid == 0)
     {
-	long fdflags;
+	/* long fdflags; */
 
 	/* child */
 	in_background = 1;

anacron-2.3-pic.patch:
 Makefile |    3 ++-
 1 files changed, 2 insertions(+), 1 deletion(-)

--- NEW FILE anacron-2.3-pic.patch ---
--- anacron-2.3/Makefile.piee	2006-10-17 12:39:39.000000000 +0200
+++ anacron-2.3/Makefile	2006-10-17 12:39:39.000000000 +0200
@@ -22,7 +22,8 @@
 PREFIX = 
 BINDIR = $(PREFIX)/usr/sbin
 MANDIR = $(PREFIX)/usr/man
-CFLAGS = -Wall -pedantic -O2
+LDFLAGS = -fpie -Wl,-z,relro
+CFLAGS = -Wall -pedantic -W -Wundef -fpie
 #CFLAGS = -Wall -O2 -g -DDEBUG
 
 # If you change these, please update the man-pages too


Index: anacron.spec
===================================================================
RCS file: /cvs/dist/rpms/anacron/devel/anacron.spec,v
retrieving revision 1.28
retrieving revision 1.29
diff -u -r1.28 -r1.29
--- anacron.spec	17 Oct 2006 11:37:36 -0000	1.28
+++ anacron.spec	4 Dec 2006 10:33:33 -0000	1.29
@@ -1,7 +1,7 @@
 Summary: A cron-like program that can run jobs lost during downtime.
 Name: anacron
 Version: 2.3
-Release: 44%{?dist}
+Release: 45%{?dist}
 License: GPL
 Group: System Environment/Base
 Source: ftp://ftp.debian.org/debian/pool/main/a/anacron/%{name}_%{version}.orig.tar.gz
@@ -16,6 +16,8 @@
 Patch6: anacron-2.3-hostname.patch
 Patch7: anacron-2.3-pie.patch
 Patch8: anacron-2.3-memoryleak.patch
+Patch9: anacron-2.3-pic.patch
+Patch10: anacron-2.3-memleaking.patch
 Requires: /bin/sh
 Requires: crontabs
 Prereq: /sbin/chkconfig
@@ -45,9 +47,10 @@
 %patch4 -p1 -b .lock-files
 %patch5 -p1 -b .fdclose
 %patch6 -p1 -b .hostname
-%patch7 -p1 -b .pie
-%patch8 -p1 -b .memoryleak
-##.memoryleak
+#%patch7 -p1 -b .pie
+#%patch8 -p1 -b .memoryleak
+%patch9 -p1 -b .pic
+%patch10 -p1 -b .memleaking
 
 %build
 make CFLAGS="$RPM_OPT_FLAGS" %{?_smp_mflags}
@@ -124,6 +127,9 @@
 %config /etc/cron.weekly/0anacron
 
 %changelog
+* Mon Dec 04 2006 Marcela Maslanova <mmaslano at redhat.com> 2.3-45
+- rebuilt with pie insted pic
+
 * Tue Oct 10 2006 Marcela Maslanova <mmaslano at redhat.com> 2.3-44
 - fix memory leaking (both #210020)
 - PIE(PIC) executable




More information about the fedora-cvs-commits mailing list
diff -ur anacron-2.3.orig/log.c anacron-2.3/log.c
--- anacron-2.3.orig/log.c	2006-10-08 09:58:47.000000000 -0400
+++ anacron-2.3/log.c	2006-10-08 10:27:29.000000000 -0400
@@ -35,6 +35,7 @@
  */
 
 #include <unistd.h>
+#include <stdlib.h>
 #include <syslog.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -79,7 +80,7 @@
 }
 
 static void
-log(int priority, const char *fmt, va_list args)
+slog(int priority, const char *fmt, va_list args)
 /* Log a message, described by "fmt" and "args", with the specified
  * "priority". */
 {
@@ -97,7 +98,7 @@
 
 static void
 log_e(int priority, const char *fmt, va_list args)
 /* Same as log(), but also appends an error description corresponding
  * to "errno". */
 {
     int saved_errno;
@@ -123,7 +124,7 @@
     va_list args;
 
     va_start(args, fmt);
-    log(EXPLAIN_LEVEL, fmt, args);
+    slog(EXPLAIN_LEVEL, fmt, args);
     va_end(args);
 }
 
@@ -145,7 +146,7 @@
     va_list args;
 
     va_start(args, fmt);
-    log(COMPLAIN_LEVEL, fmt, args);
+    slog(COMPLAIN_LEVEL, fmt, args);
     va_end(args);
 }
 
@@ -167,7 +168,7 @@
     va_list args;
 
     va_start(args, fmt);
-    log(COMPLAIN_LEVEL, fmt, args);
+    slog(COMPLAIN_LEVEL, fmt, args);
     va_end(args);
     if (getpid() == primary_pid) complain("Aborted");
 
@@ -199,7 +200,7 @@
     va_list args;
 
     va_start(args, fmt);
-    log(DEBUG_LEVEL, fmt, args);
+    slog(DEBUG_LEVEL, fmt, args);
     va_end(args);
 }
 
@@ -97,7 +98,7 @@
 static void
 log_e(int priority, const char *fmt, va_list args)
-/* Same as log(), but also appends an error description corresponding
+/* Same as slog(), but also appends an error description corresponding
  * to "errno". */
 {